# arg_robotics_tools
> A toolset for navigation (no ros) created by arg lab.


This file will become your README and also the index of your documentation.
Website : https://arg-nctu.github.io/arg_robotics_tools/

## Install

`pip install arg_robotics_tools`

We can install it locally :(or use this if above command failed)

`git clone git@github.com:ARG-NCTU/arg_robotics_tools.git`

`cd ~/arg_robotics_tools`

`pip install -e .`

## How to use

Fill me in please! Don't forget code examples:

`cd ~/arg_robotics_tools`

`source docker_run.sh`

`source colab_jupyter.sh`

click ctrl and the url to open browser, then you should see local jupyter notebook!

inside jupyter notebook, click .ipynp and run cells

## How to push

clear all notebook output

in docker : $ `make`

in your laptop, do your git push
